--[[ =================================================================
    Description:
        MailTips shows you what is attached to a mail without having
        to open the message by hovering over a message in your
        mailbox.

    Download:
        MailTips - http://redeye.xs4all.nl/mt/

    Contact:
        For questions, bug reports visit the website or send an email
        to the following address: wowaddon@xs4all.nl

    Dependencies:
        None

    Credits:
        A big 'Thank You' to all the people at Blizzard Entertainment
        for making World of Warcraft.
    ================================================================= --]]

-- Send message to the default chat frame
    function MailTips_Message( msg, prefix )
        -- Initialize
        local prefixText = "";

        -- Add application prefix
        if ( prefix ) then
            prefixText = C_GREEN.."MT: "..C_CLOSE;
        end;

        -- Send message to chatframe
        DEFAULT_CHAT_FRAME:AddMessage( prefixText..( msg or "" ) );
    end;

-- Add attached items to tooltip
    function MailTips_OnEnter( ... )
        -- Initialize
        tooltip = GameTooltip;
        items = {};

        -- Mail info
        local itemAttached = select( 8, GetInboxHeaderInfo( this.index ) );

        -- Add enclosed items to tooltip
        if ( itemAttached ) then
            -- Group items by name
            for attachID = 1, 12 do
                -- Attachment info
                local name, itemTexture, count, quality, canUse = GetInboxItem( this.index, attachID );

                -- Add it to the tooltip
                if ( count > 0 ) then
                    if ( not items[name] ) then
                        -- Work around bug introduced in WoW 2.3.3
                        if ( quality == -1 ) then
                            itemLink = GetInboxItemLink( this.index, attachID );
                            _, _, quality = GetItemInfo( itemLink );
                        end;

                        items[name] = {};
                        items[name].texture = itemTexture;
                        items[name].count = count;
                        items[name].quality = quality;
                    else
                        items[name].count = items[name].count + count;
                    end;
                end;
            end;

            -- Add items to tooltip
            if ( itemAttached > 1 ) then
                tooltip:AddLine( "|n"..MT_ENCLOSED_ITEMS );
                foreach( items, function( key, value )
                    local r, g, b, hex = GetItemQualityColor( value.quality );
                    tooltip:AddDoubleLine( "  |T"..value.texture..":0|t "..key.."  ", value.count, r, g, b );
                    --tooltip:AddDoubleLine( key, value.count, r, g, b );
                    --tooltip:AddTexture( value.texture );
                end );

                -- Forces tooltip to properly resize
                tooltip:Show();
            end;
        end;
    end;

-- Install all of the hooks used by MailTips
    function MailTips_Install_Hooks()
        -- Show startup message
        MailTips_Message( MT_STARTUP_MESSAGE, false );

        -- Save original OnEnter function
        MT_Hooks["InboxFrameItem_OnEnter"] = InboxFrameItem_OnEnter;

        -- Set new OnEnter function
        function InboxFrameItem_OnEnter( ... )
            MT_Hooks["InboxFrameItem_OnEnter"]( ... );
            MailTips_OnEnter( ... );
        end;
    end;
